@@ -20,11 +20,13 @@ from vedo.shapes import Spline
 from vedo.shapes import Text2D
 from vedo.pyplot import CornerHistogram
 
+__docformat__ = "google"
+
 __doc__ = """
 This module contains vedo applications which provide some *ready-to-use* funcionalities
-.. image:: https://vedo.embl.es/images/advanced/app_raycaster.gif
-"""
 
+<img src="https://vedo.embl.es/images/advanced/app_raycaster.gif" width="500">
+"""
 
 __all__ = [
     "Browser",
@@ -41,40 +43,8 @@ __all__ = [
 #################################
 class Slicer3DPlotter(Plotter):
     """
-    Generate a ``Plotter`` window with slicing planes for the input Volume.
-
-    Returns the ``Plotter`` object.
-
-    Parameters
-    ----------
-    alpha : float
-        transparency of the slicing planes
-
-    cmaps : list
-        list of color maps names to cycle when clicking button
-
-    map2cells : bool
-        scalars are mapped to cells, not interpolated
-
-    clamp : bool
-        clamp scalar to reduce the effect of tails in color mapping
-
-    use_slider3d : bool
-        show sliders attached along the axes
-
-    show_histo : bool
-        show histogram on bottom left
-
-    show_icon : bool
-        show a small 3D rendering icon of the volume
-
-    draggable : bool
-        make the icon draggable
-
-    .. hint:: examples/volumetric/slicer1.py
-        .. image:: https://vedo.embl.es/images/volumetric/slicer1.jpg
+    Generate a rendering window with slicing planes for the input Volume.
     """
-
     def __init__(
             self,
             volume,
@@ -96,6 +66,32 @@ class Slicer3DPlotter(Plotter):
             resetcam=True,
             interactive=True,
         ):
+        """
+        Generate a rendering window with slicing planes for the input Volume.
+     
+        Arguments:
+            alpha : (float)
+                transparency of the slicing planes
+            cmaps : (list)
+                list of color maps names to cycle when clicking button
+            map2cells : (bool)
+                scalars are mapped to cells, not interpolated
+            clamp : (bool)
+                clamp scalar to reduce the effect of tails in color mapping
+            use_slider3d : (bool)
+                show sliders attached along the axes
+            show_histo : (bool)
+                show histogram on bottom left
+            show_icon : (bool)
+                show a small 3D rendering icon of the volume
+            draggable : (bool)
+                make the icon draggable
+
+        Examples:
+            - [slicer1.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/slicer1.py)
+
+            <img src="https://vedo.embl.es/images/volumetric/slicer1.jpg" width="500">
+        """
         self._cmap_slicer= 'gist_ncar_r'
 
         if not title:
@@ -272,7 +268,8 @@ class Slicer3DPlotter(Plotter):
                     if map2cells:
                         mesh.mapPointsToCells()
             self.renderer.RemoveActor(mesh.scalarbar)
-            mesh.add_scalarbar(pos=(0.04, 0.0), horizontal=True, title_font_size=0)
+            mesh.add_scalarbar(pos=(0.04, 0.0), horizontal=True)
+            self.renderer.AddActor(mesh.scalarbar)
 
         bu = self.add_button(
             buttonfunc,
@@ -306,54 +303,36 @@ class Slicer3DPlotter(Plotter):
 ########################################################################################
 class Slicer2DPlotter(Plotter):
     """
-    Create a ``Plotter`` with a single slice of a Volume which always faces the camera,
+    A single slice of a Volume which always faces the camera,
     but at the same time can be oriented arbitrarily in space.
-
-    Parameters
-    ----------
-    levels : list
-        window and color level
-
-    .. image:: https://vedo.embl.es/images/volumetric/read_volume3.jpg
     """
-
     def __init__(
         self,
         volume,
         levels=(None, None),
-        axes=None,
-        zoom=1.2,
-        pos=(0, 0),
-        size="auto",
-        screensize="auto",
-        title="",
-        bg="white",
-        bg2=None,
-        interactive=True,
+        histo_color="red5",
+        **kwargs,
     ):
-        custom_shape = [  # define here the 2 rendering rectangle spaces
-            dict(bottomleft=(0.0, 0.0), topright=(1, 1), bg="k9"),  # the full window
-            dict(bottomleft=(0.8, 0.8), topright=(1, 1), bg="k8", bg2="lb"),
-        ]
+        """
+        A single slice of a Volume which always faces the camera,
+        but at the same time can be oriented arbitrarily in space.
 
-        if not title:
-            if volume.filename:
-                title = volume.filename[:80]
-            else:
-                title = "Volume Slicer2D"
+        Arguments:
+            levels : (list)
+                window and color levels
+            histo_color : (color)
+                histogram color, use `None` to disable it
 
-        Plotter.__init__(
-            self,
-            shape=custom_shape,
-            title=title,
-            pos=pos,
-            screensize=screensize,
-            size=size,
-            bg=bg,
-            bg2=bg2,
-            axes=0,
-            interactive=False,
-        )
+        <img src="https://vedo.embl.es/images/volumetric/read_volume3.jpg" width="500">
+        """
+        if "shape" not in kwargs:
+            custom_shape = [  # define here the 2 rendering rectangle spaces
+                dict(bottomleft=(0.0, 0.0), topright=(1, 1), bg="k9"),  # the full window
+                dict(bottomleft=(0.8, 0.8), topright=(1, 1), bg="k8", bg2="lb"),
+            ]
+            kwargs["shape"] = custom_shape
+
+        Plotter.__init__(self, **kwargs)
 
         # reuse the same underlying data as in vol
         vsl = vedo.volume.VolumeSlice(volume)
@@ -365,9 +344,9 @@ class Slicer2DPlotter(Plotter):
             vsl.lighting(window=levels[0], level=levels[1])
 
         usage = Text2D((
-            "SHIFT+Left click   \rightarrow rotate camera for oblique slicing\n"
-            "SHIFT+Middle click \rightarrow slice perpendicularly through image\n"
             "Left click & drag  \rightarrow modify luminosity and contrast\n"
+            "SHIFT+Left click   \rightarrow slice image obliquely\n"
+            "SHIFT+Middle click \rightarrow slice image perpendicularly\n"
             "R                  \rightarrow Reset the Window/Color levels\n"
             "X                  \rightarrow Reset to sagittal view\n"
             "Y                  \rightarrow Reset to coronal view\n"
@@ -379,37 +358,55 @@ class Slicer2DPlotter(Plotter):
             alpha=0.25,
         )
 
-        hist = CornerHistogram(
-            volume.pointdata[0],
-            bins=25,
-            logscale=1,
-            pos=(0.02, 0.02),
-            s=0.175,
-            c="dg",
-            bg="k",
-            alpha=1,
-        )
-        ax = None
+        hist = None
+        if histo_color is not None:
+            # hist = CornerHistogram(
+            #     volume.pointdata[0],
+            #     bins=25,
+            #     logscale=1,
+            #     pos=(0.02, 0.02),
+            #     s=0.175,
+            #     c="dg",
+            #     bg="k",
+            #     alpha=1,
+            # )
+            hist = vedo.pyplot.histogram(
+                volume.pointdata[0],
+                bins=10,
+                logscale=True,
+                c=histo_color,
+                ytitle="log_10 (counts)",
+                axes=dict(text_scale=1.9)
+            )
+            hist = hist.as2d(pos="bottom-left", scale=0.5)
+        
+        axes = kwargs.pop("axes", 7)
+        interactive = kwargs.pop("interactive", True)
         if axes == 7:
             ax = vedo.addons.RulerAxes(vsl, xtitle="x - ", ytitle="y - ", ztitle="z - ")
 
-        box = vsl.box().alpha(0.1)
-        self.at(0).show(vsl, box, ax, usage, hist, mode="image", zoom=zoom)
+        box = vsl.box().alpha(0.2)
+        self.at(0).show(vsl, box, ax, usage, hist, mode="image")
         self.at(1).show(volume, interactive=interactive)
 
 
 ########################################################################
 class RayCastPlotter(Plotter):
     """
-    Generate a ``Plotter`` window for Volume rendering using ray casting.
-
-    Returns the ``Plotter`` object.
-
-    .. hint:: examples/volumetric/app_raycaster.py
-        .. image:: https://vedo.embl.es/images/advanced/app_raycaster.gif
+    Generate Volume rendering using ray casting.
     """
-
     def __init__(self, volume, **kwargs):
+        """
+        Generate a window for Volume rendering using ray casting.
+
+        Returns:
+            `vedo.Plotter` object.
+
+        Examples:
+            - [app_raycaster.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/app_raycaster.py)
+
+            ![](https://vedo.embl.es/images/advanced/app_raycaster.gif)
+        """
 
         Plotter.__init__(self, **kwargs)
 
@@ -564,25 +561,14 @@ class RayCastPlotter(Plotter):
         plot.GetPosition2Coordinate().SetValue(0.197, 0.20, 0)
         plot.GetXAxisActor2D().SetFontFactor(0.7)
         plot.GetProperty().SetOpacity(0.5)
-        self.add([plot, volume])
+        self.add([plot, volume], render=False)
 
 
 #####################################################################################
 class IsosurfaceBrowser(Plotter):
     """
-    Generate a ``Plotter`` for Volume isosurfacing using a slider.
-
-    Set ``delayed=True`` to delay slider update on mouse release.
-
-    Set ``res`` to set the resolution, e.g. the number of desired isosurfaces to be
-    generated on the fly.
-
-    Set ``precompute=True`` to precompute the isosurfaces (so slider browsing will be smoother).
-
-    .. hint:: examples/volumetric/app_isobrowser.py
-        .. image:: https://vedo.embl.es/images/advanced/app_isobrowser.gif
+    Generate a Volume isosurfacing controlled by a slider.
     """
-
     def __init__(
             self,
             volume,
@@ -605,6 +591,21 @@ class IsosurfaceBrowser(Plotter):
             axes=1,
             interactive=True,
         ):
+        """
+        Generate a `vedo.Plotter` for Volume isosurfacing using a slider.
+    
+        Set `delayed=True` to delay slider update on mouse release.
+
+        Set `res` to set the resolution, e.g. the number of desired isosurfaces to be
+        generated on the fly.
+
+        Set `precompute=True` to precompute the isosurfaces (so slider browsing will be smoother).
+
+        Examples:
+            - [app_isobrowser.py](https://github.com/marcomusy/vedo/tree/master/examples/volumetric/app_isobrowser.py)
+
+                ![](https://vedo.embl.es/images/advanced/app_isobrowser.gif)
+        """
 
         Plotter.__init__(
             self,
@@ -712,17 +713,6 @@ class IsosurfaceBrowser(Plotter):
 class Browser(Plotter):
     """
     Browse a serie of vedo objects by using a simple slider.
-
-    Example:
-        .. code-block:: python
-
-            import vedo
-            from vedo.applications import Browser
-            meshes = vedo.load("data/2*0.vtk") # a python list
-            plt = Browser(meshes, resetcam=1, axes=4) # a vedo.Plotter
-            plt.show()
-
-    .. hint:: examples/other/morphomatics_tube.py
     """
     def __init__(
             self,
@@ -740,7 +730,20 @@ class Browser(Plotter):
             resetcam=False,
             interactive=True,
         ):
+        """
+        Browse a serie of vedo objects by using a simple slider.
 
+        Examples:
+            ```python
+            import vedo
+            from vedo.applications import Browser
+            meshes = vedo.load("data/2*0.vtk") # a python list of Meshes
+            plt = Browser(meshes, resetcam=1, axes=4) # a vedo.Plotter
+            plt.show().close()
+            ```
+
+        - [morphomatics_tube.py](https://github.com/marcomusy/vedo/tree/master/examples/other/morphomatics_tube.py)
+        """
         Plotter.__init__(
             self,
             pos=pos,
@@ -791,60 +794,7 @@ class Browser(Plotter):
 
 #############################################################################################
 class FreeHandCutPlotter(Plotter):
-    """
-    A ``Plotter`` derived class which edits polygonal meshes interactively.
-    Can also be invoked from command line. E.g. with:
-
-    ``vedo --edit https://vedo.embl.es/examples/data/porsche.ply``
-
-    Usage
-    -----
-        - Left-click and hold to rotate
-        - Right-click and move to draw line
-        - Second right-click to stop drawing
-        - Press c to clear points
-        -       z/Z to cut mesh (Z inverts inside-out the selection area)
-        -       L to keep only the largest connected surface
-        -       s to save mesh to file (tag _edited is appended to filename)
-        -       u to undo last action
-        -       h for help, i for info
-
-    Parameters
-    ----------
-    mesh : Mesh, Points
-        The input Mesh or pointcloud.
-
-    splined : bool
-        join points with a spline or a simple line.
-
-    font : str
-        Font name for the instructions.
-
-    alpha : float
-        transparency of the instruction message panel.
-
-    lw : str
-        selection line width.
-
-    lc : str
-        selection line color.
-
-    pc : str
-        selection points color.
-
-    c : str
-        backgound color of instructions.
-
-    tc : str
-        text color of instructions.
-
-    tol : int
-        tolerance of the point proximity.
-
-    .. hint:: examples/basic/cut_freehand.py
-        .. image:: https://vedo.embl.es/images/basic/cutFreeHand.gif
-    """
-
+    """A tool to edit meshes interactively."""
     # thanks to Jakub Kaminski for the original version of this script
     def __init__(
             self,
@@ -860,6 +810,53 @@ class FreeHandCutPlotter(Plotter):
             tol=0.008,
             **options
         ):
+        """
+        A `vedo.Plotter` derived class which edits polygonal meshes interactively.
+
+        Can also be invoked from command line with:
+
+        ```bash
+        vedo --edit https://vedo.embl.es/examples/data/porsche.ply
+        ```
+
+        Usage:
+            - Left-click and hold to rotate
+            - Right-click and move to draw line
+            - Second right-click to stop drawing
+            - Press "c" to clear points
+            -       "z/Z" to cut mesh (Z inverts inside-out the selection area)
+            -       "L" to keep only the largest connected surface
+            -       "s" to save mesh to file (tag `_edited` is appended to filename)
+            -       "u" to undo last action
+            -       "h" for help, "i" for info
+
+        Arguments:
+            mesh : (Mesh, Points)
+                The input Mesh or pointcloud.
+            splined : (bool)
+                join points with a spline or a simple line.
+            font : (str)
+                Font name for the instructions.
+            alpha : (float)
+                transparency of the instruction message panel.
+            lw : (str)
+                selection line width.
+            lc : (str)
+                selection line color.
+            pc : (str)
+                selection points color.
+            c : (str)
+                backgound color of instructions.
+            tc : (str)
+                text color of instructions.
+            tol : (int)
+                tolerance of the point proximity.
+
+        Examples:
+            - [cut_freehand.py](https://github.com/marcomusy/vedo/tree/master/examples/basic/cut_freehand.py)
+
+                ![](https://vedo.embl.es/images/basic/cutFreeHand.gif)
+        """
 
         if not isinstance(mesh, Points):
             vedo.logger.error("FreeHandCutPlotter input must be Points or Mesh")
@@ -896,12 +893,12 @@ class FreeHandCutPlotter(Plotter):
         self.topline = None
         self.top_pts = []
 
-    def init(self, initpoints):
+    def init(self, init_points):
         """Set an initial number of points to define a region"""
-        if isinstance(initpoints, Points):
-            self.cpoints = initpoints.points()
+        if isinstance(init_points, Points):
+            self.cpoints = init_points.points()
         else:
-            self.cpoints = np.array(initpoints)
+            self.cpoints = np.array(init_points)
         self.points = Points(self.cpoints, r=self.linewidth).c(self.pointcolor).pickable(0)
         if self.splined:
             self.spline = Spline(self.cpoints, res=len(self.cpoints) * 4)
@@ -931,7 +928,7 @@ class FreeHandCutPlotter(Plotter):
 
     def _on_mouse_move(self, evt):
         if self.drawmode:
-            cpt = self.compute_world_position(evt.picked2d) # make this 2d-screen point 3d
+            cpt = self.compute_world_coordinate(evt.picked2d) # make this 2d-screen point 3d
             if self.cpoints and mag(cpt - self.cpoints[-1]) < self.mesh.diagonal_size()*self.tol:
                 return  # new point is too close to the last one. skip
             self.cpoints.append(cpt)
@@ -1042,42 +1039,52 @@ class FreeHandCutPlotter(Plotter):
 ########################################################################
 class SplinePlotter(Plotter):
     """
-    Create an interactive application that allows the user to click points and
-    retrieve the coordinates of such points and optionally a spline or line
-    (open or closed).
-
-    Input object can be a image file name or a 3D mesh.
+    Interactive drawing of splined curves on meshes.
     """
-    def __init__(self, obj, initpoints=(), **kwargs):
+    def __init__(self, obj, init_points=(), **kwargs):
+        """
+        Create an interactive application that allows the user to click points and
+        retrieve the coordinates of such points and optionally a spline or line
+        (open or closed).
 
+        Input object can be a image file name or a 3D mesh.
+        """
         super().__init__(**kwargs)
 
         self.mode    = 'trackball'
         self.verbose = True
         self.splined = True
+        self.resolution = None  # spline resolution (None = automatic)
         self.closed  = False
         self.lcolor  = 'yellow4'
         self.lwidth  = 3
         self.pcolor  = 'purple5'
         self.psize   = 10
 
-        self.cpoints = list(initpoints)
+        self.cpoints = list(init_points)
         self.vpoints = None
         self.line = None
 
         if isinstance(obj, str):
-            self.object = vedo.Picture(obj, channels=(0,1,2))
-            # keep rgb but drop alpha channel
-            self.mode = 'image'
+            self.object = vedo.io.load(obj)
         else:
             self.object = obj
+        
+        if isinstance(self.object, vedo.Picture):
+            self.mode = 'image'
 
-        t = """Click to add a point
-        Right-click to remove it
-        Drag mouse to change constrast
-        Press c to clear points
-        Press q to continue""".replace("  ","")
-        self.instructions = Text2D(t, pos='bottom-left', c='white', bg='green', font='Calco')
+        t = (
+            "Click to add a point\n"
+            "Right-click to remove it\n"
+            "Drag mouse to change constrast\n"
+            "Press c to clear points\n"
+            "Press q to continue"
+        )
+        self.instructions = Text2D(
+            t, pos='bottom-left', c='white', bg='green', font='Calco'
+        )
+        
+        self += [self.object, self.instructions]
 
         self.callid1 = self.add_callback('KeyPress', self._key_press)
         self.callid2 = self.add_callback('LeftButtonPress', self._on_left_click)
@@ -1092,7 +1099,14 @@ class SplinePlotter(Plotter):
         return np.array(self.cpoints)
 
     def _on_left_click(self, evt):
-        if not evt.actor: return
+        if not evt.actor: 
+            return
+        if evt.actor.name == "points":
+            # remove clicked point if clicked twice
+            pid = self.vpoints.closest_point(evt.picked3d, return_point_id=True)
+            self.cpoints.pop(pid)
+            self._update()
+            return
         p = evt.picked3d
         self.cpoints.append(p)
         self._update()
@@ -1109,14 +1123,15 @@ class SplinePlotter(Plotter):
     def _update(self):
         self.remove(self.line, self.vpoints)  # remove old points and spline
         self.vpoints = Points(self.cpoints).ps(self.psize).c(self.pcolor)
-        self.vpoints.pickable(False)  # avoid picking the same point
+        self.vpoints.name = "points"
+        self.vpoints.pickable(True)  # to allow toggle
         minnr = 1
         if self.splined:
             minnr = 2
-        if len(self.cpoints) > minnr:
+        if self.lwidth and len(self.cpoints) > minnr:
             if self.splined:
                 try:
-                    self.line = Spline(self.cpoints, closed=self.closed)
+                    self.line = Spline(self.cpoints, closed=self.closed, res=self.resolution)
                 except ValueError:
                     # if clicking too close splining might fail
                     self.cpoints.pop()
@@ -1144,25 +1159,20 @@ class SplinePlotter(Plotter):
 ########################################################################
 class Animation(Plotter):
     """
-    A ``Plotter`` derived class that allows to animate simultaneously various objects
+    A `Plotter` derived class that allows to animate simultaneously various objects
     by specifying event times and durations of different visual effects.
 
-    Parameters
-    ----------
-    total_duration : float
-        expand or shrink the total duration of video to this value
-
-    time_resolution : float
-        in seconds, save a frame at this rate
-
-    show_progressbar : bool
-        whether to show a progress bar or not
-
-    video_filename : str
-        output file name of the video
-
-    video_fps : int
-        desired value of the nr of frames per second
+    Arguments:
+        total_duration : (float)
+            expand or shrink the total duration of video to this value
+        time_resolution : (float)
+            in seconds, save a frame at this rate
+        show_progressbar : (bool)
+            whether to show a progress bar or not
+        video_filename : (str)
+            output file name of the video
+        video_fps : (int)
+            desired value of the nr of frames per second
 
     .. warning:: this is still an experimental feature at the moment.
     """
@@ -1550,33 +1560,35 @@ class Animation(Plotter):
 
 
 class Clock(vedo.Assembly):
-    """
-    Create a clock with current time or user provided time.
+    """Clock animation."""
+    def __init__(
+            self,
+            h=None,
+            m=None,
+            s=None,
+            font="Quikhand",
+            title="",
+            c="k",
+        ):
+        """
+        Create a clock with current time or user provided time.
 
-    Parameters
-    ----------
-    h : int
-        hours in range [0,23]
-
-    m : int
-        minutes in range [0,59]
-
-    s : int
-        seconds in range [0,59]
-
-    font : str
-        font type
-
-    title : str
-        some extra text to show on the clock
-
-    c : str
-        color of the numbers
-
-
-    Example:
-        .. code-block:: python
+        Arguments:
+            h : (int)
+                hours in range [0,23]
+            m : (int)
+                minutes in range [0,59]
+            s : (int)
+                seconds in range [0,59]
+            font : (str)
+                font type
+            title : (str)
+                some extra text to show on the clock
+            c : (str)
+                color of the numbers
 
+        Example:
+            ```python
             import time
             from vedo import show
             from vedo.applications import Clock
@@ -1587,16 +1599,9 @@ class Clock(vedo.Assembly):
                 clock.update()
                 plt.render()
             plt.close()
-    """
-    def __init__(
-            self,
-            h=None,
-            m=None,
-            s=None,
-            font="Quikhand",
-            title="",
-            c="k",
-        ):
+            ```
+            ![](https://vedo.embl.es/images/feats/clock.png)
+        """
         self.elapsed = 0
         self._start = time.time()
 
@@ -1608,19 +1613,12 @@ class Clock(vedo.Assembly):
             s = t.tm_sec
             if not title:
                 d = ["Mon","Tue","Wed","Thu","Fri","Sat","Sun"]
-                wd = d[t.tm_wday] + " "
+                wd = f"{d[t.tm_wday]} {t.tm_mday}/{t.tm_mon}/{t.tm_year} "
 
         h = int(h) % 24
         m = int(m) % 60
         t = (h*60+m) / 12 / 60
 
-        if not title:
-            if h<10:
-                h = f"0{h}"
-            if m<10:
-                m = f"0{m}"
-            title = f"{h}:{m}"
-
         alpha = 2*np.pi*t + np.pi/2
         beta  = 12*2*np.pi*t + np.pi/2
 
@@ -1637,18 +1635,20 @@ class Clock(vedo.Assembly):
         if s is not None:
             secs= Line([0,0], [x3,y3], lw=1, c='k').scale(0.95).mirror()
             secs.z(0.003)
-        back1 = vedo.shapes.Circle(res=180, c="k6").lw(1)
-        back2 = vedo.shapes.Circle(res=12).mirror().scale(0.86).rotate_z(-360/12)
+        back1 = vedo.shapes.Circle(res=180, c="k5")
+        back2 = vedo.shapes.Circle(res=12).mirror().scale(0.84).rotate_z(-360/12)
         labels = back2.labels(
             range(1,13),
             justify="center",
             font=font,
             c=c,
+            scale=0.14,
         )
-        txt = vedo.shapes.Text3D(wd+title,
+        txt = vedo.shapes.Text3D(
+            wd + title,
             font="VictorMono",
             justify="top-center",
-            s=.1,
+            s=0.07,
             c=c,
         )
         txt.pos(0,-0.25, 0.001)
@@ -1658,7 +1658,7 @@ class Clock(vedo.Assembly):
         self.name = "Clock"
 
     def update(self, h=None, m=None, s=None):
-        """Update clock with current or user time"""
+        """Update clock with current or user time."""
         parts = self.unpack()
         self.elapsed = time.time() - self._start
 
