@@ -1,24 +1,30 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 """
 Command Line Interface module
 -----------------------------
+The library includes a handy Command Line Interface.
+
+    # For a list of options type:
 
-    # Type for help
     vedo -h
 
     # Some useful bash aliases:
+    #
     alias v='vedo '
-    alias vr='vedo --run '        # to search and run examples by name
-    alias vs='vedo -i --search '  # to search for a string in examples
-    alias ve='vedo --eog '        # to view single and multiple images (press h for help)
+    alias vr='vedo --run '             # to search and run examples by name
+    alias vs='vedo -i --search '       # to search for a string in examples
+    alias vdoc='vedo -i --search-code' # to search for a string in source code
+    alias ve='vedo --eog '             # to view single and multiple images
+    #
     alias vv='vedo -bg blackboard -bg2 gray3 -z 1.05 -k glossy -c blue9 '
 """
 import argparse
 import glob
 import os
 import sys
-
 import numpy as np
 
 try:
@@ -57,7 +63,6 @@ def execute_cli():
     if "\\vedo\\vedo" in vedo.installdir:
         vedo.installdir = vedo.installdir.replace("vedo\\", "")
 
-
     if args.info is not None:
         system_info()
 
@@ -70,6 +75,9 @@ def execute_cli():
     elif args.search_vtk:
         exe_search_vtk(args)
 
+    elif args.search_code:
+        exe_search_code(args)
+
     elif args.convert:
         exe_convert(args)
 
@@ -77,7 +85,8 @@ def execute_cli():
         exe_eog(args)
 
     elif len(args.files) == 0:
-        exe_gui(args)
+        system_info()
+        printc("No input files. Try:\n> vedo https://vedo.embl.es/examples/data/panther.stl.gz", c="y")
 
     else:
         draw_scene(args)
@@ -116,16 +125,17 @@ def get_parser():
     pr.add_argument("-e", "--edit",                 help="free-hand edit the input Mesh", action="store_true")
     pr.add_argument("--slicer2d",                   help="2D Slicer Mode for volumetric data", action="store_true")
     pr.add_argument("--slicer3d",                   help="3D Slicer Mode for volumetric data", action="store_true")
-    pr.add_argument("--lego",                       help="voxel rendering for 3D image files", action="store_true")
     pr.add_argument("-r", "--run",                  help="run example from vedo/examples", metavar='')
     pr.add_argument("--search",           type=str, help="search/grep for word in vedo examples", default='', metavar='')
     pr.add_argument("--search-vtk",       type=str, help="search examples for the input vtk class", default='', metavar='')
+    pr.add_argument("--search-code",      type=str, help="search keyword in source code", default='', metavar='')
     pr.add_argument("--reload",                     help="reload the file, ignoring any previous download", action="store_true")
     pr.add_argument("--info", nargs='*',            help="get an info printout of the input file(s)")
     pr.add_argument("--convert", nargs='*',         help="input file(s) to be converted")
     pr.add_argument("--to",               type=str, help="convert to this target format", default='vtk', metavar='')
     pr.add_argument("--image",                      help="image mode for 2d objects", action="store_true")
     pr.add_argument("--eog",                        help="eog-like image visualizer", action="store_true")
+    pr.add_argument("--font",                       help="font name", default="Normografo", metavar='')
     return pr
 
 
@@ -155,8 +165,14 @@ def system_info():
     printc("vedo installation :", vedo.installdir)
     try:
         import platform
-        printc("system            :", platform.system(),
-               platform.release(), os.name, platform.machine())
+
+        printc(
+            "system            :",
+            platform.system(),
+            platform.release(),
+            os.name,
+            platform.machine(),
+        )
     except ModuleNotFoundError:
         pass
 
@@ -166,8 +182,10 @@ def system_info():
         for m in get_monitors():
             pr = "         "
             if m.is_primary:
-                pr = '(primary)'
-            printc(f"monitor {pr} : {m.name}, resolution=({m.width}, {m.height}), x={m.x}, y={m.y}")
+                pr = "(primary)"
+            printc(
+                f"monitor {pr} : {m.name}, resolution=({m.width}, {m.height}), x={m.x}, y={m.y}"
+            )
     except ModuleNotFoundError:
         printc('monitor           : info is unavailable. Try "pip install screeninfo".')
 
@@ -177,24 +195,18 @@ def system_info():
         printc("k3d version       :", k3d.__version__, bold=0, dim=1)
     except ModuleNotFoundError:
         pass
+
     try:
         import ipyvtk_simple
 
         printc("ipyvtk version    :", ipyvtk_simple.__version__, bold=0, dim=1)
     except ModuleNotFoundError:
         pass
-    try:
-        import itkwidgets
-
-        printc("itkwidgets version:", itkwidgets.__version__, bold=0, dim=1)
-    except ModuleNotFoundError:
-        pass
-    try:
-        import panel
-
-        printc("panel version     :", panel.__version__, bold=0, dim=1)
-    except ModuleNotFoundError:
-        pass
+    # try:
+    #     import trame
+    #     printc("trame version     :", trame.__version__, bold=0, dim=1)
+    # except ModuleNotFoundError:
+    #     pass
 
 
 #################################################################################################
@@ -205,7 +217,9 @@ def exe_run(args):
     matching = [
         s
         for s in exfiles
-        if (f2search in os.path.basename(s).lower() and "__" not in s)
+        if (f2search in os.path.basename(s).lower() 
+            and "__" not in s and "dolfin" not in s and "trimesh" not in s
+        )
     ]
     matching = list(sorted(matching))
     nmat = len(matching)
@@ -245,20 +259,14 @@ def exe_run(args):
             code = fm.read()
         code = "#" * 80 + "\n" + code + "\n" + "#" * 80
 
-        try:
-            from pygments import highlight
-            from pygments.lexers import Python3Lexer
-            from pygments.formatters import Terminal256Formatter
+        from pygments import highlight
+        from pygments.lexers import Python3Lexer
+        from pygments.formatters import Terminal256Formatter
 
-            # from pygments.styles import STYLE_MAP
-            # print(STYLE_MAP.keys())
-            result = highlight(code, Python3Lexer(), Terminal256Formatter(style='zenburn'))
-            print(result, end='')
-
-        except ModuleNotFoundError:
-            printc(code, italic=1, bold=0)
-            printc("To colorize code try:  pip install Pygments")
-        # print()
+        # from pygments.styles import STYLE_MAP
+        # print(STYLE_MAP.keys())
+        result = highlight(code, Python3Lexer(), Terminal256Formatter(style="zenburn"))
+        print(result, end="")
 
     printc("(" + matching[0] + ")", c="y", bold=0, italic=1)
     os.system("python " + matching[0])
@@ -315,6 +323,10 @@ def exe_search(args):
         pattern = pattern.lower()
     if len(pattern) > 3:
         for ifile in exfiles:
+            if "dolfin" in ifile:
+                continue
+            if "trimesh" in ifile:
+                continue
             with open(ifile, "r", encoding="UTF-8") as file:
                 fflag = True
                 for i, line in enumerate(file):
@@ -336,7 +348,103 @@ def exe_search(args):
                         print(f"\u001b[33m{i}\t{line}\x1b[0m", end='')
                         # printc(i, line, c='o', bold=False, end='')
     else:
-        printc("Please specify at least four characters.", c="r")
+        printc("Please use at least 4 letters in keyword search!", c="r")
+
+
+##############################################################################################
+def exe_search_code(args):
+
+    import inspect
+    from pygments import highlight
+    from pygments.lexers import Python3Lexer
+    from pygments.formatters import Terminal256Formatter
+
+    # styles: autumn, material, rrt, zenburn
+    style = "zenburn"
+    key = args.search_code
+    iopt = args.no_camera_share
+    if key.lower() == key:
+        iopt = True
+
+    if len(key) < 4:
+        printc("Please use at least 4 letters in keyword search!", c="r")
+        return
+
+    def _dump(mcontent):
+        for name, mm in mcontent:
+            if name.startswith("_"):
+                continue
+            if name.startswith("vtk"):
+                continue
+            # if not inspect.isfunction(mm):
+            #     continue
+
+            try:
+                mmdoc = inspect.getsource(mm)
+            except TypeError:
+                return
+
+            if mmdoc is None:
+                continue
+
+            if iopt:
+                # -i option to ignore case
+                mmdoc_lower = mmdoc.lower()
+                key_lower = key.lower()
+                name_lower = name.lower()
+            else:
+                mmdoc_lower = mmdoc
+                key_lower = key
+                name_lower = name
+
+            if "eprecated" in mmdoc_lower:
+                continue
+
+            if key_lower in name_lower:
+
+                sname = inspect.getmodule(mm).__name__ + " -> " + name
+                if sname in snames:
+                    continue
+                snames.append(sname)
+
+                printc(
+                    "Found matching",
+                    mm,
+                    "in module",
+                    os.path.basename(inspect.getfile(mm)),
+                    c="y",
+                    invert=True,
+                )
+                mmdoc = mmdoc.replace("``", '"').replace("`", '"')
+                mmdoc = mmdoc.replace(".. warning::", "Warning!")
+                result = highlight(
+                    mmdoc,
+                    Python3Lexer(),
+                    Terminal256Formatter(style=style),
+                )
+                idcomment = result.rfind('"""')
+                print(result[: idcomment + 3], "\x1b[0m\n")
+
+    printc("..parsing source code, please wait", c="y", bold=False)
+    content = inspect.getmembers(vedo)
+    snames = []
+    for name, m in content:
+        if name.startswith("_"):
+            continue
+        if not inspect.isclass(m) and not inspect.isfunction(m):
+            continue
+        if inspect.isbuiltin(m):
+            continue
+
+        # if name != "Points": continue # test
+        # printc("---", name, str(m), c='r')
+
+        # function case
+        _dump([[name, m]])
+
+        # class case
+        mcontent = inspect.getmembers(m)
+        _dump(mcontent)
 
 
 ##############################################################################################
@@ -513,7 +621,8 @@ def exe_eog(args):
         plt.show(interactive=False)
         plt.reset_camera(tight=0.05)
         plt.interactor.Start()
-        if vedo.vtk_version == (9,2,2): plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
+        if vedo.vtk_version == (9, 2, 2):
+            plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
 
     else:
 
@@ -534,7 +643,8 @@ def exe_eog(args):
         plt.show(pic, mode="image", interactive=False)
         plt.reset_camera(tight=0.0)
         plt.interactor.Start()
-        if vedo.vtk_version == (9,2,2): plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
+        if vedo.vtk_version == (9, 2, 2):
+            plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
 
     plt.close()
 
@@ -569,6 +679,7 @@ def draw_scene(args):
 
     if args.scrolling_mode:
         args.multirenderer_mode = False
+    settings.default_font = args.font
 
     N = None
     if args.multirenderer_mode:
@@ -614,13 +725,9 @@ def draw_scene(args):
         sp = vol.spacing()
         vol.spacing([sp[0]*args.x_spacing, sp[1]*args.y_spacing, sp[2]*args.z_spacing])
         vol.mode(int(args.mode)).color(args.cmap).jittering(True)
-        # if args.lighting !='default':
-        vol.lighting(args.lighting).jittering(True)
+        vol.lighting(args.lighting)
         plt = applications.RayCastPlotter(vol)
-        plt.show(viewup="z", interactive=True)
-        plt.sliders[0][0].SetEnabled(False)
-        plt.sliders[1][0].SetEnabled(False)
-        plt.sliders[2][0].SetEnabled(False)
+        plt.show(viewup="z", interactive=True).close()
         return
 
     ##########################################################
@@ -691,7 +798,7 @@ def draw_scene(args):
         return
 
     ########################################################################
-    # normal mode for single VOXEL file with Isosurface Slider or LEGO mode
+    # normal mode for single VOXEL file with Isosurface Slider mode
     elif nfiles == 1 and (
         ".slc" in args.files[0].lower()
         or ".vti" in args.files[0].lower()
@@ -700,7 +807,7 @@ def draw_scene(args):
         or ".nrrd" in args.files[0].lower()
         or ".dem" in args.files[0].lower()
     ):
-        # print('DEBUG normal mode for single VOXEL file with Isosurface Slider or LEGO mode')
+        # print('DEBUG normal mode for single VOXEL file with Isosurface Slider mode')
         vol = io.load(args.files[0], force=args.reload)
         sp = vol.spacing()
         vol.spacing(
@@ -710,10 +817,8 @@ def draw_scene(args):
             args.color = "gold"
         plt = applications.IsosurfaceBrowser(
             vol,
-            lego=args.lego,
             c=args.color,
             cmap=args.cmap,
-            delayed=args.lego,
             precompute=True,
             progress=True,
         )
@@ -788,17 +893,14 @@ def draw_scene(args):
                     plt.camera.SetClippingRange(0, ds)
                     plt.show(actor, at=i, interactive=False, zoom=args.zoom, mode=interactor_mode)
                     plt.actors = actors
-                    # if args.no_camera_share: ## BUG
-                    # plt.reset_camera()
-                    # plt.renderers[i].ResetCameraClippingRange()
-                    # print([plt.camera])
                 except AttributeError:
                     # wildcards in quotes make glob return actor as a list :(
                     vedo.logger.error("Please do not use wildcards within single or double quotes")
 
         if args.multirenderer_mode:
             plt.interactor.Start()
-            if vedo.vtk_version == (9,2,2): plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
+            if vedo.vtk_version == (9, 2, 2):
+                plt.interactor.GetRenderWindow().SetDisplayId("_0_p_void")
 
         else:
 
@@ -845,310 +947,3 @@ def draw_scene(args):
 
         plt = applications.Browser(acts, axes=1)
         plt.show(zoom=args.zoom).close()
-
-
-########################################################################
-def exe_gui(args):
-
-    # print('DEBUG gui started')
-    if sys.version_info[0] > 2:
-        from tkinter import Frame, Tk, BOTH, Label, Scale, Checkbutton, BooleanVar, StringVar
-        from tkinter.ttk import Button, Style, Combobox, Entry
-        from tkinter import filedialog as tkFileDialog
-    else:
-        from Tkinter import Frame, Tk, BOTH, Label, Scale, Checkbutton, BooleanVar, StringVar
-        from ttk import Button, Style, Combobox, Entry
-        import tkFileDialog
-
-    ######################
-    class vedoGUI(Frame):
-        def __init__(self, parent):
-            Frame.__init__(self, parent, bg="white")
-            self.parent = parent
-            self.filenames = []
-            self.noshare = BooleanVar()
-            self.flat = BooleanVar()
-            self.xspacing = StringVar()
-            self.yspacing = StringVar()
-            self.zspacing = StringVar()
-            self.background_grad = BooleanVar()
-            self.initUI()
-
-        def initUI(self):
-            self.parent.title("vedo")
-            self.style = Style()
-            self.style.theme_use("clam")
-            self.pack(fill=BOTH, expand=True)
-
-            ############import
-            Button(self, text="Import Files", command=self._importCMD, width=15).place(
-                x=115, y=17
-            )
-
-            ############meshes
-            Frame(root, height=1, width=398, bg="grey").place(x=1, y=60)
-            Label(
-                self, text="Meshes", fg="white", bg="green", font=("Courier 11 bold")
-            ).place(x=20, y=65)
-
-            # color
-            Label(self, text="Color:", bg="white").place(x=30, y=98)
-            colvalues = (
-                "by scalar",
-                "gold",
-                "red",
-                "green",
-                "blue",
-                "coral",
-                "plum",
-                "tomato",
-            )
-            self.color_cb = Combobox(self, state="readonly", values=colvalues, width=10)
-            self.color_cb.current(0)
-            self.color_cb.place(x=100, y=98)
-
-            # mode
-            modvalues = ("surface", "surf. & edges", "wireframe", "point cloud")
-            self.surfmode_cb = Combobox(
-                self, state="readonly", values=modvalues, width=14
-            )
-            self.surfmode_cb.current(0)
-            self.surfmode_cb.place(x=205, y=98)
-
-            # alpha
-            Label(self, text="Alpha:", bg="white").place(x=30, y=145)
-            self.alpha_cb = Scale(
-                self,
-                from_=0,
-                to=1,
-                resolution=0.02,
-                bg="white",
-                length=220,
-                orient="horizontal",
-            )
-            self.alpha_cb.set(1.0)
-            self.alpha_cb.place(x=100, y=125)
-
-            # lighting
-            Label(self, text="Lighting:", bg="white").place(x=30, y=180)
-            lightvalues = ("default", "metallic", "plastic", "shiny", "glossy", "off")
-            self.light_cb = Combobox(
-                self, state="readonly", values=lightvalues, width=10
-            )
-            self.light_cb.current(0)
-            self.light_cb.place(x=100, y=180)
-            # shading phong or flat
-            self.flat_cb = Checkbutton(
-                self, text="flat shading", var=self.flat, bg="white"
-            )
-            # self.flat_cb.select()
-            self.flat_cb.place(x=210, y=180)
-
-            # rendering arrangement
-            Label(self, text="Arrange as:", bg="white").place(x=30, y=220)
-            schemevalues = (
-                "superpose (default)",
-                "mesh browser",
-                "n sync-ed renderers",
-            )
-            self.schememode_cb = Combobox(
-                self, state="readonly", values=schemevalues, width=20
-            )
-            self.schememode_cb.current(0)
-            self.schememode_cb.place(x=160, y=220)
-
-            # share cam
-            self.noshare_cb = Checkbutton(
-                self, text="independent cameras", variable=self.noshare, bg="white"
-            )
-            self.noshare_cb.place(x=160, y=245)
-
-            ############volumes
-            Frame(root, height=1, width=398, bg="grey").place(x=1, y=275)
-            Label(
-                self, text="Volumes", fg="white", bg="blue", font=("Courier 11 bold")
-            ).place(x=20, y=280)
-
-            # mode
-            Label(self, text="Rendering mode:", bg="white").place(x=30, y=310)
-            modevalues = (
-                "isosurface (default)",
-                "composite",
-                "maximum proj",
-                "lego",
-                "slicer2d",
-                "slicer3d",
-            )
-            self.mode_cb = Combobox(self, state="readonly", values=modevalues, width=20)
-            self.mode_cb.current(0)
-            self.mode_cb.place(x=160, y=310)
-
-            Label(self, text="Spacing factors:", bg="white").place(x=30, y=335)
-            self.xspacing_cb = Entry(self, textvariable=self.xspacing, width=3)
-            self.xspacing.set("1.0")
-            self.xspacing_cb.place(x=160, y=335)
-            self.yspacing_cb = Entry(self, textvariable=self.yspacing, width=3)
-            self.yspacing.set("1.0")
-            self.yspacing_cb.place(x=210, y=335)
-            self.zspacing_cb = Entry(self, textvariable=self.zspacing, width=3)
-            self.zspacing.set("1.0")
-            self.zspacing_cb.place(x=260, y=335)
-
-            ############## options
-            Frame(root, height=1, width=398,bg="grey").place(x=1, y=370)
-            Label(self, text="Options", fg='white', bg="brown", font=("Courier 11 bold")).place(x=20, y=375)
-
-            # backgr color
-            Label(self, text="Background color:", bg="white").place(x=30, y=405)
-            bgcolvalues = ("white", "lightyellow", "azure", "blackboard", "black")
-            self.bgcolor_cb = Combobox(self, state="readonly", values=bgcolvalues, width=9)
-            self.bgcolor_cb.current(3)
-            self.bgcolor_cb.place(x=160, y=405)
-            # backgr color gradient
-            self.backgroundGrad_cb = Checkbutton(
-                self, text="gradient", variable=self.background_grad, bg="white"
-            )
-            self.backgroundGrad_cb.place(x=255, y=405)
-
-            ################ render button
-            Frame(root, height=1, width=398, bg="grey").place(x=1, y=437)
-            Button(self, text="Render", command=self._run, width=15).place(x=115, y=454)
-
-        def _importCMD(self):
-            ftypes = [
-                ("All files", "*"),
-                ("VTK files", "*.vtk"),
-                ("VTK files", "*.vtp"),
-                ("VTK files", "*.vts"),
-                ("VTK files", "*.vtu"),
-                ("Surface Mesh", "*.ply"),
-                ("Surface Mesh", "*.obj"),
-                ("Surface Mesh", "*.stl"),
-                ("Surface Mesh", "*.off"),
-                ("Surface Mesh", "*.facet"),
-                ("Volume files", "*.tif"),
-                ("Volume files", "*.slc"),
-                ("Volume files", "*.vti"),
-                ("Volume files", "*.mhd"),
-                ("Volume files", "*.nrrd"),
-                ("Volume files", "*.nii"),
-                ("Volume files", "*.dem"),
-                ("Picture files", "*.png"),
-                ("Picture files", "*.jpg"),
-                ("Picture files", "*.bmp"),
-                ("Picture files", "*.gif"),
-                ("Picture files", "*.jpeg"),
-                ("Geojson files", "*.geojson"),
-                ("DOLFIN files", "*.xml.gz"),
-                ("DOLFIN files", "*.xml"),
-                ("DOLFIN files", "*.xdmf"),
-                ("Neutral mesh", "*.neu*"),
-                ("GMESH", "*.gmsh"),
-                ("Point Cloud", "*.pcd"),
-                ("3DS", "*.3ds"),
-                ("Numpy scene file", "*.npy"),
-                ("Numpy scene file", "*.npz"),
-            ]
-            self.filenames = tkFileDialog.askopenfilenames(parent=root, filetypes=ftypes)
-            args.files = list(self.filenames)
-
-        def _run(self):
-
-            args.files = list(self.filenames)
-            if self.color_cb.get() == "by scalar":
-                args.color = None
-            else:
-                if self.color_cb.get() == "red":
-                    args.color = "crimson"
-                elif self.color_cb.get() == "green":
-                    args.color = "limegreen"
-                elif self.color_cb.get() == "blue":
-                    args.color = "darkcyan"
-                else:
-                    args.color = self.color_cb.get()
-
-            args.alpha = self.alpha_cb.get()
-
-            args.wireframe = False
-            args.showedges = False
-            args.point_size = 0
-            if self.surfmode_cb.get() == "point cloud":
-                args.point_size = 2
-            elif self.surfmode_cb.get() == "wireframe":
-                args.wireframe = True
-            elif self.surfmode_cb.get() == "surf. & edges":
-                args.showedges = True
-            else:
-                pass  # normal surface mode
-
-            args.lighting = self.light_cb.get()
-            args.flat = self.flat.get()
-
-            args.no_camera_share = self.noshare.get()
-            args.background = self.bgcolor_cb.get()
-
-            args.background_grad = None
-            if self.background_grad.get():
-                b = get_color(args.background)
-                args.background_grad = (b[0] / 1.8, b[1] / 1.8, b[2] / 1.8)
-
-            args.multirenderer_mode = False
-            args.scrolling_mode = False
-            if self.schememode_cb.get() == "n sync-ed renderers":
-                args.multirenderer_mode = True
-            elif self.schememode_cb.get() == "mesh browser":
-                args.scrolling_mode = True
-
-            args.ray_cast_mode = False
-            args.lego = False
-            args.slicer3d = False
-            args.slicer2d = False
-            args.lego = False
-            args.mode = 0
-            if self.mode_cb.get() == "composite":
-                args.ray_cast_mode = True
-                args.mode = 0
-            elif self.mode_cb.get() == "maximum proj":
-                args.ray_cast_mode = True
-                args.mode = 1
-            elif self.mode_cb.get() == "slicer3d":
-                args.slicer3d = True
-            elif self.mode_cb.get() == "slicer2d":
-                args.slicer2d = True
-            elif self.mode_cb.get() == "lego":
-                args.lego = True
-
-            args.x_spacing = 1
-            args.y_spacing = 1
-            args.z_spacing = 1
-            if self.xspacing.get() != "1.0":
-                args.x_spacing = float(self.xspacing.get())
-            if self.yspacing.get() != "1.0":
-                args.y_spacing = float(self.yspacing.get())
-            if self.zspacing.get() != "1.0":
-                args.z_spacing = float(self.zspacing.get())
-
-            draw_scene(args)
-            if os.name == "nt":
-                sys.exit()
-            if vedo.plotter_instance:
-                vedo.plotter_instance.close()
-
-    root = Tk()
-    root.geometry("360x500")
-    app = vedoGUI(root)
-
-    def tkcallback(event):
-        # printc("xy cursor position:", event.x, event.y, event.char)
-        if event.char == "q":
-            root.destroy()
-
-    app.bind("<Key>", tkcallback)
-    app.focus_set()
-    app.pack()
-
-    if os.name == "nt" and len(sys.argv) > 1:
-        app.filenames = sys.argv[1:]
-        print("Already", len(app.filenames), "files loaded.")
-
-    root.mainloop()
