@@ -11,53 +11,39 @@ import vedo
 from vedo.colors import printc
 from vedo import utils
 from vedo import shapes
-from vedo.io import download, export_window, load, screenshot, Video
 from vedo.mesh import Mesh
-from vedo.plotter import Plotter
 from vedo.plotter import show
-from vedo.shapes import Text2D, Text3D
-from vedo.utils import ProgressBar
+
+__docformat__ = "google"
 
 __doc__ = """
 Submodule for support of the [FEniCS/Dolfin](https://fenicsproject.org) library.
 
 Example:
-    .. code-block:: python
+    ```python
+    import dolfin
+    from vedo import dataurl, download
+    from vedo.dolfin import plot
+    fname = download(dataurl+"dolfin_fine.xml")
+    mesh = dolfin.Mesh(fname)
+    plot(mesh)
+    ```
 
-        import dolfin
-        from vedo.dolfin import dataurl, download, plot
-        fname = download(dataurl+"dolfin_fine.xml")
-        mesh = dolfin.Mesh(fname)
-        plot(mesh)
+![](https://user-images.githubusercontent.com/32848391/53026243-d2d31900-3462-11e9-9dde-518218c241b6.jpg)
 
-    .. image:: https://user-images.githubusercontent.com/32848391/53026243-d2d31900-3462-11e9-9dde-518218c241b6.jpg
-
-Find many more examples in
-[vedo/examples/dolfin](https://github.com/marcomusy/vedo/blob/master/vedo/examples/other/dolfin).
-
-.. image:: https://user-images.githubusercontent.com/32848391/58368591-8b3fab80-7eef-11e9-882f-8b8eaef43567.gif
+.. note::
+    Find many more examples in directory    
+    [vedo/examples/dolfin](https://github.com/marcomusy/vedo/blob/master/examples/other/dolfin).
 """
 
-
 __all__ = [
     "plot",
-    "load",
-    "download",
-    "show",
-    "printc",
-    "Plotter",
-    "ProgressBar",
-    "Text3D",
-    "Text2D",
-    "screenshot",
-    "Video",
-    "export_window",
 ]
 
 
 ##########################################################################
 def _inputsort(obj):
-# def _inputsort_dolfin(obj):
+
     import dolfin
 
     u = None
@@ -174,224 +160,162 @@ def plot(*inputobj, **options):
     """
     Plot the object(s) provided.
 
-    Input can be any combination of: ``Mesh``, ``Volume``, ``dolfin.Mesh``,
-    ``dolfin.MeshFunction``, ``dolfin.Expression`` or ``dolfin.Function``.
+    Input can be any combination of: `Mesh`, `Volume`, `dolfin.Mesh`,
+    `dolfin.MeshFunction`, `dolfin.Expression` or `dolfin.Function`.
 
-    Return the current ``Plotter`` class instance.
+    Return the current `Plotter` class instance.
 
-    Parameters
-    ----------
-    mode : str
-        one or more of the following can be combined in any order
-
-        - `mesh`/`color`, will plot the mesh, by default colored with a scalar if available
-        - `displacement` show displaced mesh by solution
-        - `arrows`, mesh displacements are plotted as scaled arrows.
-        - `lines`, mesh displacements are plotted as scaled lines.
-        - `tensors`, to be implemented
-
-    add : bool
-        add the input objects without clearing the already plotted ones
-
-    density : float
-        show only a subset of lines or arrows [0-1]
-
-    wire[frame] : bool
-        visualize mesh as wireframe [False]
-
-    c[olor] : color
-        set mesh color [None]
-
-    exterior : bool
-        only show the outer surface of the mesh [False]
-
-    alpha : float
-        set object's transparency [1]
-
-    lw : int
-        line width of the mesh (set to zero to hide mesh) [0.1]
-
-    ps :  int
-        set point size of mesh vertices [None]
-
-    z : float
-        add a constant to z-coordinate (useful to show 2D slices as function of time)
-
-    legend : str
-        add a legend to the top-right of window [None]
-
-    scalarbar : bool
-        add a scalarbar to the window ['vertical']
-
-    vmin : float
-        set the minimum for the range of the scalar [None]
-
-    vmax : float
-        set the maximum for the range of the scalar [None]
-
-    scale : float
-        add a scaling factor to arrows and lines sizes [1]
-
-    cmap : str
-        choose a color map for scalars
-
-    shading : str
-        mesh shading ['flat', 'phong']
-
-    text : str
-        add a gray text comment to the top-left of the window [None]
-
-    isolines : dict
-        dictionary of isolines properties
-
-        - n, (int) - add this number of isolines to the mesh
-        - c, - isoline color
-        - lw, (float) - isoline width
-        - z, (float) - add to the isoline z coordinate to make them more visible
-
-
-    streamlines : dict
-        dictionary of streamlines properties
-
-        - probes, (list, None) - custom list of points to use as seeds
-        - tol, (float) - tolerance to reduce the number of seed points used in mesh
-        - lw, (float) - line width of the streamline
-        - direction, (str) - direction of integration ('forward', 'backward' or 'both')
-        - max_propagation, (float) - max propagation of the streamline
-        - scalar_range, (list) - scalar range of coloring
-
-
-    warpZfactor : float
-        elevate z-axis by scalar value (useful for 2D geometries)
-
-    warpYfactor : float
-        elevate z-axis by scalar value (useful for 1D geometries)
-
-    scaleMeshFactors : list
-        rescale mesh by these factors [1,1,1]
-
-    new : bool
-        spawn a new instance of Plotter class, pops up a new window
-
-    at : int
-        renderer number to plot to
-
-    shape : list
-        subdvide window in (n,m) rows and columns
-
-    N : int
-        automatically subdvide window in N renderers
-
-    pos : list
-        (x,y) coordinates of the window position on screen
-
-    size : list
-        window size (x,y)
-
-    title : str
-        window title
-
-    bg : color
-        background color name of window
-
-    bg2 : color
-        second background color name to create a color gradient
-
-    style : int
-        choose a predefined style [0-4]
-
-          - 0, `vedo`, style (blackboard background, rainbow color map)
-          - 1, `matplotlib`, style (white background, viridis color map)
-          - 2, `paraview`, style
-          - 3, `meshlab`, style
-          - 4, `bw`, black and white style.
-
-    axes : int
-        Axes type number.
-        Axes type-1 can be fully customized by passing a dictionary ``axes=dict()``.
-
-           - 0,  no axes,
-           - 1,  draw customizable grid axes (see below).
-           - 2,  show cartesian axes from (0,0,0)
-           - 3,  show positive range of cartesian axes from (0,0,0)
-           - 4,  show a triad at bottom left
-           - 5,  show a cube at bottom left
-           - 6,  mark the corners of the bounding box
-           - 7,  draw a simple ruler at the bottom of the window
-           - 8,  show the `vtkCubeAxesActor` object,
-           - 9,  show the bounding box outLine,
-           - 10, show three circles representing the maximum bounding box,
-           - 11, show a large grid on the x-y plane (use with zoom=8)
-           - 12, show polar axes.
-
-    infinity : bool
-        if True fugue point is set at infinity (no perspective effects)
-
-    sharecam : bool
-        if False each renderer will have an independent vtkCamera
-
-    interactive : bool
-        if True will stop after show() to allow interaction w/ window
-
-    offscreen : bool
-        if True will not show the rendering window
-
-    zoom : float
-        camera zooming factor
-
-    viewup : list, str
-        camera view-up direction ['x','y','z', or a vector direction]
-
-    azimuth : float
-        add azimuth rotation of the scene, in degrees
-
-    elevation : float
-        add elevation rotation of the scene, in degrees
-
-    roll : float
-        add roll-type rotation of the scene, in degrees
-
-    camera : dict
-        Camera parameters can further be specified with a dictionary
-        assigned to the ``camera`` keyword:
-        (E.g. `show(camera={'pos':(1,2,3), 'thickness':1000,})`)
-
-        - `pos`, `(list)`,
-            the position of the camera in world coordinates
-
-        - `focal_point`, `(list)`,
-            the focal point of the camera in world coordinates
-
-        - `viewup`, `(list)`,
-            the view up direction for the camera
-
-        - `distance`, `(float)`,
-            set the focal point to the specified distance from the camera position.
-
-        - `clippingRange`, `(float)`,
-            distance of the near and far clipping planes along the direction of projection.
-
-        - `parallelScale`, `(float)`,
-            scaling used for a parallel projection, i.e. the height of the viewport
-            in world-coordinate distances. The default is 1. Note that the "scale" parameter works as
-            an "inverse scale", larger numbers produce smaller images.
-            This method has no effect in perspective projection mode.
-
-        - `thickness`, `(float)`,
-            set the distance between clipping planes. This method adjusts the far clipping
-            plane to be set a distance 'thickness' beyond the near clipping plane.
-
-        - `viewAngle`, `(float)`,
-            the camera view angle, which is the angular height of the camera view
-            measured in degrees. The default angle is 30 degrees.
-            This method has no effect in parallel projection mode.
-            The formula for setting the angle up for perfect perspective viewing is:
-            angle = 2*atan((h/2)/d) where h is the height of the RenderWindow
-            (measured by holding a ruler up to your screen) and d is the distance
-            from your eyes to the screen.
-
-    interactorStyle : int
-        change the style of muose interaction of the scene
+    Arguments:
+        mode : (str)
+            one or more of the following can be combined in any order
+            - `mesh`/`color`, will plot the mesh, by default colored with a scalar if available
+            - `displacement` show displaced mesh by solution
+            - `arrows`, mesh displacements are plotted as scaled arrows.
+            - `lines`, mesh displacements are plotted as scaled lines.
+            - `tensors`, to be implemented
+        add : (bool)
+            add the input objects without clearing the already plotted ones
+        density : (float)
+            show only a subset of lines or arrows [0-1]
+        wire[frame] : (bool)
+            visualize mesh as wireframe [False]
+        c[olor] : (color)
+            set mesh color [None]
+        exterior : (bool)
+            only show the outer surface of the mesh [False]
+        alpha : (float)
+            set object's transparency [1]
+        lw : (int)
+            line width of the mesh (set to zero to hide mesh) [0.1]
+        ps :  int
+            set point size of mesh vertices [None]
+        z : (float)
+            add a constant to z-coordinate (useful to show 2D slices as function of time)
+        legend : (str)
+            add a legend to the top-right of window [None]
+        scalarbar : (bool)
+            add a scalarbar to the window ['vertical']
+        vmin : (float)
+            set the minimum for the range of the scalar [None]
+        vmax : (float)
+            set the maximum for the range of the scalar [None]
+        scale : (float)
+            add a scaling factor to arrows and lines sizes [1]
+        cmap : (str)
+            choose a color map for scalars
+        shading : (str)
+            mesh shading ['flat', 'phong']
+        text : (str)
+            add a gray text comment to the top-left of the window [None]
+        isolines : (dict)
+            dictionary of isolines properties
+            - n, (int) - add this number of isolines to the mesh
+            - c, - isoline color
+            - lw, (float) - isoline width
+            - z, (float) - add to the isoline z coordinate to make them more visible
+        streamlines : (dict)
+            dictionary of streamlines properties
+            - probes, (list, None) - custom list of points to use as seeds
+            - tol, (float) - tolerance to reduce the number of seed points used in mesh
+            - lw, (float) - line width of the streamline
+            - direction, (str) - direction of integration ('forward', 'backward' or 'both')
+            - max_propagation, (float) - max propagation of the streamline
+            - scalar_range, (list) - scalar range of coloring
+        warpZfactor : (float)
+            elevate z-axis by scalar value (useful for 2D geometries)
+        warpYfactor : (float)
+            elevate z-axis by scalar value (useful for 1D geometries)
+        scaleMeshFactors : (list)
+            rescale mesh by these factors [1,1,1]
+        new : (bool)
+            spawn a new instance of Plotter class, pops up a new window
+        at : (int)
+            renderer number to plot to
+        shape : (list)
+            subdvide window in (n,m) rows and columns
+        N : (int)
+            automatically subdvide window in N renderers
+        pos : (list)
+            (x,y) coordinates of the window position on screen
+        size : (list)
+            window size (x,y)
+        title : (str)
+            window title
+        bg : (color)
+            background color name of window
+        bg2 : (color)
+            second background color name to create a color gradient
+        style : (int)
+            choose a predefined style [0-4]
+            - 0, `vedo`, style (blackboard background, rainbow color map)
+            - 1, `matplotlib`, style (white background, viridis color map)
+            - 2, `paraview`, style
+            - 3, `meshlab`, style
+            - 4, `bw`, black and white style.
+        axes : (int)
+            Axes type number.
+            Axes type-1 can be fully customized by passing a dictionary `axes=dict()`.
+            - 0,  no axes,
+            - 1,  draw customizable grid axes (see below).
+            - 2,  show cartesian axes from (0,0,0)
+            - 3,  show positive range of cartesian axes from (0,0,0)
+            - 4,  show a triad at bottom left
+            - 5,  show a cube at bottom left
+            - 6,  mark the corners of the bounding box
+            - 7,  draw a simple ruler at the bottom of the window
+            - 8,  show the `vtkCubeAxesActor` object,
+            - 9,  show the bounding box outLine,
+            - 10, show three circles representing the maximum bounding box,
+            - 11, show a large grid on the x-y plane (use with zoom=8)
+            - 12, show polar axes.
+        infinity : (bool)
+            if True fugue point is set at infinity (no perspective effects)
+        sharecam : (bool)
+            if False each renderer will have an independent vtkCamera
+        interactive : (bool)
+            if True will stop after show() to allow interaction w/ window
+        offscreen : (bool)
+            if True will not show the rendering window
+        zoom : (float)
+            camera zooming factor
+        viewup : (list), str
+            camera view-up direction ['x','y','z', or a vector direction]
+        azimuth : (float)
+            add azimuth rotation of the scene, in degrees
+        elevation : (float)
+            add elevation rotation of the scene, in degrees
+        roll : (float)
+            add roll-type rotation of the scene, in degrees
+        camera : (dict)
+            Camera parameters can further be specified with a dictionary
+            assigned to the `camera` keyword:
+            (E.g. `show(camera={'pos':(1,2,3), 'thickness':1000,})`)
+            - `pos`, `(list)`,
+                the position of the camera in world coordinates
+            - `focal_point`, `(list)`,
+                the focal point of the camera in world coordinates
+            - `viewup`, `(list)`,
+                the view up direction for the camera
+            - `distance`, `(float)`,
+                set the focal point to the specified distance from the camera position.
+            - `clipping_range`, `(float)`,
+                distance of the near and far clipping planes along the direction of projection.
+            - `parallel_scale`, `(float)`,
+                scaling used for a parallel projection, i.e. the height of the viewport
+                in world-coordinate distances. The default is 1. Note that the "scale" parameter works as
+                an "inverse scale", larger numbers produce smaller images.
+                This method has no effect in perspective projection mode.
+            - `thickness`, `(float)`,
+                set the distance between clipping planes. This method adjusts the far clipping
+                plane to be set a distance 'thickness' beyond the near clipping plane.
+            - `view_angle`, `(float)`,
+                the camera view angle, which is the angular height of the camera view
+                measured in degrees. The default angle is 30 degrees.
+                This method has no effect in parallel projection mode.
+                The formula for setting the angle up for perfect perspective viewing is:
+                angle = 2*atan((h/2)/d) where h is the height of the RenderWindow
+                (measured by holding a ruler up to your screen) and d is the distance
+                from your eyes to the screen.
     """
     if len(inputobj) == 0:
         vedo.plotter_instance.interactive()
@@ -437,7 +361,6 @@ def plot(*inputobj, **options):
     warpYfactor = options.pop("warpYfactor", None)
     lighting = options.pop("lighting", None)
     exterior = options.pop("exterior", False)
-    fast = options.pop("fast", False)
     returnActorsNoShow = options.pop("returnActorsNoShow", False)
     at = options.pop("at", 0)
 
@@ -537,7 +460,7 @@ def plot(*inputobj, **options):
 
     if mesh and ("mesh" in mode or "color" in mode or "displace" in mode):
 
-        actor = MeshActor(u, mesh, exterior=exterior, fast=fast)
+        actor = MeshActor(u, mesh, exterior=exterior)
 
         actor.wireframe(wire)
         actor.scale(scaleMeshFactors)
@@ -572,8 +495,8 @@ def plot(*inputobj, **options):
         if "displace" in mode:
             actor.move(u)
 
-        if cmap and (actor.u_values is not None) and c is None:
-            if u.value_rank() > 0:  # will show the size of the vector
+        if cmap and (actor.u_values is not None) and len(actor.u_values) and c is None:
+            if actor.u_values.ndim > 1:
                 actor.cmap(cmap, utils.mag(actor.u_values), vmin=vmin, vmax=vmax)
             else:
                 actor.cmap(cmap, actor.u_values, vmin=vmin, vmax=vmax)
@@ -680,14 +603,13 @@ def plot(*inputobj, **options):
 
 ###################################################################################
 class MeshActor(Mesh):
-    """MeshActor, a vedo.Mesh derived object for dolfin support."""
-
+    """MeshActor for dolfin support."""
     def __init__(self, *inputobj, **options):
+        """MeshActor, a `vedo.Mesh` derived object for dolfin support."""
 
         c = options.pop("c", None)
         alpha = options.pop("alpha", 1)
         exterior = options.pop("exterior", False)
-        fast = options.pop("fast", False)
         compute_normals = options.pop("compute_normals", False)
 
         mesh, u = _inputsort(inputobj)
@@ -706,7 +628,70 @@ class MeshActor(Mesh):
         else:
             coords = mesh.geometry.points
 
-        poly = utils.buildPolyData(coords, meshc.cells(), fast=fast, tetras=True)
+        cells = meshc.cells()
+
+        if cells.shape[1] == 4:
+            # something wrong in this as it cannot reproduce the tet cell..
+            # from vedo.tetmesh import _buildtetugrid
+            # cells[:,[2, 0]] = cells[:,[0, 2]]
+            # cells[:,[1, 0]] = cells[:,[0, 1]]
+            # cells[:,[0, 1, 2, 3]] = cells[:,[0, 2, 1, 3]]
+            # cells[:,[0, 1, 2, 3]] = cells[:,[0, 2, 1, 3]]
+            # cells[:,[0, 1, 2, 3]] = cells[:,  [0, 1, 3, 2]]
+            # cells[:,[0, 1, 2, 3]] = cells[:,[1, 0, 2, 3]]
+            # cells[:,[0, 1, 2, 3]] = cells[:,[2, 0, 1, 3]]
+            # cells[:,[0, 1, 2, 3]] = cells[:,[2, 0, 1, 3]]
+            # print(cells[0])
+            # print(coords[cells[0]])
+            # poly = utils.geometry(_buildtetugrid(coords, cells))
+            # poly = utils.geometry(vedo.TetMesh([coords, cells]).inputdata())
+
+            poly = vtk.vtkPolyData()
+
+            source_points = vtk.vtkPoints()
+            source_points.SetData(utils.numpy2vtk(coords, dtype=np.float32))
+            poly.SetPoints(source_points)
+
+            source_polygons = vtk.vtkCellArray()
+            for f in cells:
+                # do not use vtkTetra() because it fails
+                # with dolfin faces orientation
+                ele0 = vtk.vtkTriangle()
+                ele1 = vtk.vtkTriangle()
+                ele2 = vtk.vtkTriangle()
+                ele3 = vtk.vtkTriangle()
+
+                f0, f1, f2, f3 = f
+                pid0 = ele0.GetPointIds()
+                pid1 = ele1.GetPointIds()
+                pid2 = ele2.GetPointIds()
+                pid3 = ele3.GetPointIds()
+
+                pid0.SetId(0, f0)
+                pid0.SetId(1, f1)
+                pid0.SetId(2, f2)
+
+                pid1.SetId(0, f0)
+                pid1.SetId(1, f1)
+                pid1.SetId(2, f3)
+
+                pid2.SetId(0, f1)
+                pid2.SetId(1, f2)
+                pid2.SetId(2, f3)
+
+                pid3.SetId(0, f2)
+                pid3.SetId(1, f3)
+                pid3.SetId(2, f0)
+
+                source_polygons.InsertNextCell(ele0)
+                source_polygons.InsertNextCell(ele1)
+                source_polygons.InsertNextCell(ele2)
+                source_polygons.InsertNextCell(ele3)
+
+            poly.SetPolys(source_polygons)
+
+        else:
+            poly = utils.buildPolyData(coords, cells)
 
         Mesh.__init__(
             self,
@@ -748,12 +733,12 @@ class MeshActor(Mesh):
         movedpts = coords + deltas
         if movedpts.shape[1] == 2:  # 2d
             movedpts = np.c_[movedpts, np.zeros(movedpts.shape[0])]
-        self.polydata(False).GetPoints().SetData(utils.numpy2vtk(movedpts, dtype=float))
+        self.polydata(False).GetPoints().SetData(utils.numpy2vtk(movedpts, dtype=np.float32))
         self.polydata(False).GetPoints().Modified()
 
 
 def MeshPoints(*inputobj, **options):
-    """Build a point object of type ``Mesh`` for a list of points."""
+    """Build a point object of type `Mesh` for a list of points."""
     r = options.pop("r", 5)
     c = options.pop("c", "gray")
     alpha = options.pop("alpha", 1)
@@ -794,12 +779,12 @@ def MeshPoints(*inputobj, **options):
 def MeshLines(*inputobj, **options):
     """
     Build the line segments between two lists of points `start_points` and `end_points`.
-    `start_points` can be also passed in the form ``[[point1, point2], ...]``.
+    `start_points` can be also passed in the form `[[point1, point2], ...]`.
 
-    A dolfin ``Mesh`` that was deformed/modified by a function can be
+    A dolfin `Mesh` that was deformed/modified by a function can be
     passed together as inputs.
 
-    Use ``scale`` to apply a rescaling factor to the length
+    Use `scale` to apply a rescaling factor to the length
     """
     scale = options.pop("scale", 1)
     lw = options.pop("lw", 1)
