@@ -6,43 +6,64 @@ try:
 except ImportError:
     import vtkmodules.all as vtk
 
+import numpy as np
 import vedo
 from vedo import utils
 from vedo.base import BaseGrid
 from vedo.mesh import Mesh
 from vedo.io import download, loadUnStructuredGrid
 
-__doc__ = """
-Work with tetrahedral meshes
 
-.. image:: https://vedo.embl.es/images/volumetric/82767107-2631d500-9e25-11ea-967c-42558f98f721.jpg
+__docformat__ = "google"
+
+__doc__ = """
+Work with tetrahedral meshes.
+
+![](https://vedo.embl.es/images/volumetric/82767107-2631d500-9e25-11ea-967c-42558f98f721.jpg)
 """
 
 __all__ = ["TetMesh", "delaunay3d"]
 
 
 ##########################################################################
-def delaunay3d(mesh, alpha_parameter=0, tol=None, boundary=False):
-    """Create 3D Delaunay triangulation of input points."""
+def delaunay3d(mesh, radius=0, tol=None):
+    """
+    Create 3D Delaunay triangulation of input points.
+
+    Arguments:
+    
+        radius : (float)
+            specify distance (or "alpha") value to control output.
+            For a non-zero values, only tetra contained within the circumsphere
+            will be output.
+
+        tol : (float)
+            Specify a tolerance to control discarding of closely spaced points.
+            This tolerance is specified as a fraction of the diagonal length of
+            the bounding box of the points.
+    """
     deln = vtk.vtkDelaunay3D()
     if utils.is_sequence(mesh):
         pd = vtk.vtkPolyData()
         vpts = vtk.vtkPoints()
-        vpts.SetData(utils.numpy2vtk(mesh, dtype=float))
+        vpts.SetData(utils.numpy2vtk(mesh, dtype=np.float32))
         pd.SetPoints(vpts)
         deln.SetInputData(pd)
     else:
         deln.SetInputData(mesh.GetMapper().GetInput())
-    deln.SetAlpha(alpha_parameter)
+    deln.SetAlpha(radius)
     deln.AlphaTetsOn()
     deln.AlphaTrisOff()
     deln.AlphaLinesOff()
     deln.AlphaVertsOff()
+    deln.BoundingTriangulationOff()
     if tol:
         deln.SetTolerance(tol)
-    deln.SetBoundingTriangulation(boundary)
     deln.Update()
     m = TetMesh(deln.GetOutput())
+    m.pipeline = utils.OperationNode(
+        "delaunay3d", c="#e9c46a:#edabab", parents=[mesh],
+    )
     return m
 
 
@@ -69,23 +90,23 @@ def _buildtetugrid(points, cells):
         cells = tets
 
     source_points = vtk.vtkPoints()
-    varr = utils.numpy2vtk(points, dtype=float)
+    varr = utils.numpy2vtk(points, dtype=np.float32)
     source_points.SetData(varr)
     ug.SetPoints(source_points)
 
-    sourceTets = vtk.vtkCellArray()
+    source_tets = vtk.vtkCellArray()
     for f in cells:
         ele = vtk.vtkTetra()
         pid = ele.GetPointIds()
         for i, fi in enumerate(f):
             pid.SetId(i, fi)
-        sourceTets.InsertNextCell(ele)
-    ug.SetCells(vtk.VTK_TETRA, sourceTets)
+        source_tets.InsertNextCell(ele)
+    ug.SetCells(vtk.VTK_TETRA, source_tets)
     return ug
 
 
 ##########################################################################
-class TetMesh(vtk.vtkVolume, BaseGrid):
+class TetMesh(BaseGrid, vtk.vtkVolume):
     """The class describing tetrahedral meshes."""
 
     def __init__(
@@ -93,10 +114,19 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         inputobj=None,
         c=("r", "y", "lg", "lb", "b"),  # ('b','lb','lg','y','r')
         alpha=(0.5, 1),
-        alphaUnit=1,
+        alpha_unit=1,
         mapper="tetra",
     ):
-
+        """
+        Arguments:
+            inputobj : (vtkDataSet, list, str)
+                list of points and tet indices, or filename
+            alpha_unit : (float)
+                opacity scale
+            mapper : (str)
+                choose a visualization style in `['tetra', 'raycast', 'zsweep']`
+        """
+        vtk.vtkVolume.__init__(self)
         BaseGrid.__init__(self)
 
         self.useArray = 0
@@ -157,15 +187,93 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         self._mapper.SetInputData(self._data)
         self.SetMapper(self._mapper)
         self.color(c).alpha(alpha)
-        if alphaUnit:
-            self.GetProperty().SetScalarOpacityUnitDistance(alphaUnit)
+        if alpha_unit:
+            self.GetProperty().SetScalarOpacityUnitDistance(alpha_unit)
 
         # remember stuff:
         self._color = c
         self._alpha = alpha
-        self._alphaUnit = alphaUnit
+        self._alpha_unit = alpha_unit
+
+        self.pipeline = utils.OperationNode(
+            self, comment=f"#tets {self._data.GetNumberOfCells()}",
+            c="#9e2a2b",
+        )
         # -----------------------------------------------------------
 
+    def _repr_html_(self):
+        """
+        HTML representation of the TetMesh object for Jupyter Notebooks.
+        
+        Returns:
+            HTML text with the image and some properties.
+        """
+        import io
+        import base64
+        from PIL import Image
+
+        library_name = "vedo.tetmesh.TetMesh"
+        help_url = "https://vedo.embl.es/docs/vedo/tetmesh.html"
+
+        arr = self.thumbnail()
+        im = Image.fromarray(arr)
+        buffered = io.BytesIO()
+        im.save(buffered, format="PNG", quality=100)
+        encoded = base64.b64encode(buffered.getvalue()).decode("utf-8")
+        url = "data:image/png;base64," + encoded
+        image = f"<img src='{url}'></img>"
+
+        bounds = "<br/>".join(
+            [
+                utils.precision(min_x,4) + " ... " + utils.precision(max_x,4)
+                for min_x, max_x in zip(self.bounds()[::2], self.bounds()[1::2])
+            ]
+        )
+
+        help_text = ""
+        if self.name:
+            help_text += f"<b> {self.name}: &nbsp&nbsp</b>"
+        help_text += '<b><a href="' + help_url + '" target="_blank">' + library_name + "</a></b>" 
+        if self.filename:
+            dots = ""
+            if len(self.filename) > 30:
+                dots = "..."
+            help_text += f"<br/><code><i>({dots}{self.filename[-30:]})</i></code>"
+        
+        pdata = ""
+        if self._data.GetPointData().GetScalars():
+            if self._data.GetPointData().GetScalars().GetName():
+                name = self._data.GetPointData().GetScalars().GetName()
+                pdata = "<tr><td><b> point data array </b></td><td>" + name + "</td></tr>"
+
+        cdata = ""
+        if self._data.GetCellData().GetScalars():
+            if self._data.GetCellData().GetScalars().GetName():
+                name = self._data.GetCellData().GetScalars().GetName()
+                cdata = "<tr><td><b> cell data array </b></td><td>" + name + "</td></tr>"
+
+        pts = self.points()
+        cm = np.mean(pts, axis=0)
+
+        all = [
+            "<table>",
+            "<tr>", 
+            "<td>", image, "</td>",
+            "<td style='text-align: center; vertical-align: center;'><br/>", help_text,
+            "<table>",
+            "<tr><td><b> bounds </b> <br/> (x/y/z) </td><td>" + str(bounds) + "</td></tr>",
+            "<tr><td><b> center of mass </b></td><td>" + utils.precision(cm,3) + "</td></tr>",
+            # "<tr><td><b> average size </b></td><td>" + str(average_size) + "</td></tr>",
+            "<tr><td><b> nr. points&nbsp/&nbsptets </b></td><td>" 
+            + str(self.npoints) + "&nbsp/&nbsp" + str(self.ncells) + "</td></tr>",
+            pdata,
+            cdata,
+            "</table>",
+            "</table>",
+        ]
+        return "\n".join(all)
+
+
     def _update(self, data):
         self._data = data
         self.mapper().SetInputData(data)
@@ -173,7 +281,7 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         return self
 
     def clone(self):
-        """Clone the ``TetMesh`` object to yield an exact copy."""
+        """Clone the `TetMesh` object to yield an exact copy."""
         ugCopy = vtk.vtkUnstructuredGrid()
         ugCopy.DeepCopy(self._data)
 
@@ -190,6 +298,10 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
 
         cloned.mapper().SetScalarMode(self.mapper().GetScalarMode())
         cloned.name = self.name
+
+        cloned.pipeline = utils.OperationNode(
+            "clone", c="#edabab", shape="diamond", parents=[self],
+        )
         return cloned
 
     def compute_quality(self, metric=7):
@@ -197,25 +309,21 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         Calculate functions of quality for the elements of a triangular mesh.
         This method adds to the mesh a cell array named "Quality".
 
-        Parameters
-        ----------
-        metric : int
-            type of estimator
+        Arguments:
+            metric : (int)
+                type of estimators:
+                    - EDGE RATIO, 0
+                    - ASPECT RATIO, 1
+                    - RADIUS RATIO, 2
+                    - ASPECT FROBENIUS, 3
+                    - MIN_ANGLE, 4
+                    - COLLAPSE RATIO, 5
+                    - ASPECT GAMMA, 6
+                    - VOLUME, 7
+                    - ...
 
-                - EDGE RATIO, 0
-                - ASPECT RATIO, 1
-                - RADIUS RATIO, 2
-                - ASPECT FROBENIUS, 3
-                - MIN_ANGLE, 4
-                - COLLAPSE RATIO, 5
-                - ASPECT GAMMA, 6
-                - VOLUME, 7
-                - ...
-                See class [vtkMeshQuality](https://vtk.org/doc/nightly/html/classvtkMeshQuality.html)
-                for explanation.
-
-        .. hint:: meshquality.py
-            .. image:: https://vedo.embl.es/images/advanced/meshquality.png
+        See class [vtkMeshQuality](https://vtk.org/doc/nightly/html/classvtkMeshQuality.html)
+        for an explanation of the meaning of each metric..
         """
         qf = vtk.vtkMeshQuality()
         qf.SetInputData(self._data)
@@ -226,7 +334,7 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         return utils.vtk2numpy(qf.GetOutput().GetCellData().GetArray("Quality"))
 
     def compute_tets_volume(self):
-        """Add to this mesh a cell data array containing the areas of the polygonal faces"""
+        """Add to this mesh a cell data array containing the tetrahedron volume."""
         csf = vtk.vtkCellSizeFilter()
         csf.SetInputData(self._data)
         csf.SetComputeArea(False)
@@ -241,20 +349,20 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
     def check_validity(self, tol=0):
         """
         Return an array of possible problematic tets following this convention:
+        ```python
+        Valid               =  0
+        WrongNumberOfPoints = 01
+        IntersectingEdges   = 02
+        IntersectingFaces   = 04
+        NoncontiguousEdges  = 08
+        Nonconvex           = 10
+        OrientedIncorrectly = 20
+        ```
 
-            Valid               =  0
-            WrongNumberOfPoints = 01
-            IntersectingEdges   = 02
-            IntersectingFaces   = 04
-            NoncontiguousEdges  = 08
-            Nonconvex           = 10
-            OrientedIncorrectly = 20
-
-        Parameters
-        ----------
-        tol : float
-            This value is used as an epsilon for floating point
-            equality checks throughout the cell checking process.
+        Arguments:
+            tol : (float)
+                This value is used as an epsilon for floating point
+                equality checks throughout the cell checking process.
         """
         vald = vtk.vtkCellValidator()
         if tol:
@@ -268,10 +376,11 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         """
         Threshold the tetrahedral mesh by a cell scalar value.
         Reduce to only tets which satisfy the threshold limits.
-        If ``above==below`` will only select tets with that specific value.
-        If ``above > below`` selection range is "flipped" (vtk_version>8).
 
-        Set keyword `on` either to a "cells" or "points".
+        - if `above = below` will only select tets with that specific value.
+        - if `above > below` selection range is flipped.
+
+        Set keyword "on" to either "cells" or "points".
         """
         th = vtk.vtkThreshold()
         th.SetInputData(self._data)
@@ -312,46 +421,54 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         th.Update()
         return self._update(th.GetOutput())
 
-    def decimate(self, scalars_name, fraction=0.5, N=None):
+    def decimate(self, scalars_name, fraction=0.5, n=0):
         """
         Downsample the number of tets in a TetMesh to a specified fraction.
+        Either `fraction` or `n` must be set.
 
-        Parameters
-        ----------
-        fraction : float
-            the desired final fraction of the total.
+        Arguments:
+            fraction : (float)
+                the desired final fraction of the total.
+            n : (int)
+                the desired number of final tets
 
-        N : int
-            the desired number of final tets
-
-        .. note:: Setting ``fraction=0.1`` leaves 10% of the original nr of tets.
+        .. note:: setting `fraction=0.1` leaves 10% of the original nr of tets.
         """
         decimate = vtk.vtkUnstructuredGridQuadricDecimation()
         decimate.SetInputData(self._data)
         decimate.SetScalarsName(scalars_name)
 
-        if N:  # N = desired number of points
-            decimate.SetNumberOfTetsOutput(N)
+        if n:  # n = desired number of points
+            decimate.SetNumberOfTetsOutput(n)
         else:
             decimate.SetTargetReduction(1 - fraction)
         decimate.Update()
-        return self._update(decimate.GetOutput())
+        self._update(decimate.GetOutput())
+        self.pipeline = utils.OperationNode(
+            "decimate", comment=f"array: {scalars_name}",
+            c="#edabab", parents=[self],
+        )
+        return self
 
     def subdvide(self):
         """
-        Increase the number of tets of a TetMesh.
+        Increase the number of tets of a `TetMesh`.
         Subdivide one tetrahedron into twelve for every tetra.
         """
         sd = vtk.vtkSubdivideTetra()
         sd.SetInputData(self._data)
         sd.Update()
-        return self._update(sd.GetOutput())
+        self._update(sd.GetOutput())
+        self.pipeline = utils.OperationNode(
+            "subdvide", c="#edabab", parents=[self],
+        )
+        return self
 
     def isosurface(self, value=True):
         """
-        Return a ``Mesh`` isosurface.
+        Return a `vedo.Mesh` isosurface.
 
-        Set `value` to a single value or list of values to compute the isosurface(s)
+        Set `value` to a single value or list of values to compute the isosurface(s).
         """
         if not self._data.GetPointData().GetScalars():
             self.map_cells_to_points()
@@ -367,8 +484,6 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         else:
             if value is True:
                 value = (2 * scrange[0] + scrange[1]) / 3.0
-                # print('automatic value set to ' + utils.precision(value, 3), end=' ')
-                # print('in [' + utils.precision(scrange[0], 3) + ', ' + utils.precision(scrange[1], 3)+']')
             cf.SetValue(0, value)
             cf.Update()
 
@@ -377,11 +492,13 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         clp.Update()
         msh = Mesh(clp.GetOutput(), c=None).phong()
         msh.mapper().SetLookupTable(utils.ctf2lut(self))
+        msh.pipeline = utils.OperationNode("isosurface", c="#edabab", parents=[self])
         return msh
 
     def slice(self, origin=(0, 0, 0), normal=(1, 0, 0)):
         """
-        Return a 2D slice of the mesh by a plane passing through origin and assigned normal."""
+        Return a 2D slice of the mesh by a plane passing through origin and assigned normal.
+        """
         strn = str(normal)
         if strn   ==  "x": normal = (1, 0, 0)
         elif strn ==  "y": normal = (0, 1, 0)
@@ -399,4 +516,5 @@ class TetMesh(vtk.vtkVolume, BaseGrid):
         cc.Update()
         msh = Mesh(cc.GetOutput()).flat().lighting("ambient")
         msh.mapper().SetLookupTable(utils.ctf2lut(self))
+        msh.pipeline = utils.OperationNode("slice", c="#edabab", parents=[self])
         return msh
